@@ -20,7 +20,6 @@ import hashlib
 
 from oslo_serialization import jsonutils as json
 from oslo_utils import timeutils
-import six
 import sqlalchemy as sa
 from sqlalchemy.ext import compiler
 from sqlalchemy.ext import declarative
@@ -195,7 +194,7 @@ class ModelBase(object):
 
     def _iso_to_datetime(self, expiration):
         """Convert ISO formatted string to datetime."""
-        if isinstance(expiration, six.string_types):
+        if isinstance(expiration, str):
             expiration_iso = timeutils.parse_isotime(expiration.strip())
             expiration = timeutils.normalize_time(expiration_iso)
 
@@ -374,14 +373,13 @@ class Secret(BASE, SoftDeleteMixIn, ModelBase):
             'bit_length': self.bit_length,
             'mode': self.mode,
             'creator_id': self.creator_id,
-            # TODO(redrobot): Uncomment this after adding microversions
-            # "consumers": [
-            #     {
-            #         "service": consumer.service,
-            #         "resource_type": consumer.resource_type,
-            #         "resource_id": consumer.resource_id,
-            #     } for consumer in self.consumers if not consumer.deleted
-            # ],
+            "consumers": [
+                {
+                    "service": consumer.service,
+                    "resource_type": consumer.resource_type,
+                    "resource_id": consumer.resource_id,
+                } for consumer in self.consumers if not consumer.deleted
+            ],
         }
 
 
@@ -1529,7 +1527,8 @@ class SecretConsumerMetadatum(BASE, SoftDeleteMixIn, ModelBase):
 
     __table_args__ = (
         sa.UniqueConstraint(
-            "secret_id", "resource_id", name="_secret_consumer_resource_uc"
+            "secret_id", "service", "resource_type", "resource_id",
+            name="_secret_consumer_resource_uc"
         ),
     )
 
