@@ -26,8 +26,7 @@ from oslo_config import cfg
 from oslo_utils import uuidutils
 import oslotest.base as oslotest
 from oslotest import createfile
-import six
-from six.moves.urllib import parse
+from urllib import parse
 import webtest
 
 from barbican.api import app
@@ -41,12 +40,13 @@ from barbican.plugin import kmip_secret_store as kss
 from barbican.tests import database_utils
 
 
-def mock_pecan_request(test_instance, host=None):
+def mock_pecan_request(test_instance, host=None, version='1.0'):
     patcher_obj = mock.patch('pecan.request')
     mock_req = patcher_obj.start()
     test_instance.addCleanup(patcher_obj.stop)
     mock_req.url = host
     mock_req.environ = os.environ.copy()
+    mock_req.environ['key-manager.microversion'] = version
     mock_req.application_url = host
 
 
@@ -373,11 +373,11 @@ def construct_new_test_function(original_func, name, build_params):
     :return: A new function object
     """
     new_func = types.FunctionType(
-        six.get_function_code(original_func),
-        six.get_function_globals(original_func),
+        original_func.__code__,
+        original_func.__globals__,
         name=name,
-        argdefs=six.get_function_defaults(original_func),
-        closure=six.get_function_closure(original_func)
+        argdefs=original_func.__defaults__,
+        closure=original_func.__closure__
     )
 
     for key, val in original_func.__dict__.items():
@@ -684,3 +684,8 @@ def is_pkcs11_enabled():
 
 class DummyClassForTesting(object):
     pass
+
+
+def set_version(app, version):
+    """Sets the requested version in the environ"""
+    app.extra_environ['key-manager.microversion'] = version
